@@ -511,15 +511,16 @@ WeekCalendarTool.prototype = {
                 }
             }
         }
-		
+        
 		var id = this.object[0];
 		var folder = this.object[1];
 		var recurrencePos = this.object[2] || 0;	
 		var title = this.object[3];
 		var start_date = this.object[4];
 		var end_date = this.object[5];
-		var note = this.object[6];
-		var recurrenceType = this.object[7];
+		//var note = this.object[6];
+		//var recurrenceType = this.object[7];
+		var users = this.object[8];
 		var isFullTime = this.object[9];
 		var shownAs = this.object[10];
 		var colorLabel = this.object[11];
@@ -636,10 +637,10 @@ WeekCalendarTool.prototype = {
 		}
 		
 		// setting confirmation styles
-		if (participants.length) {
-			for (var i in participants) {
-				if (participants[i].id == owner) {
-					switch(participants[i].confirmation) {
+		if (users.length) {
+			for (var i in users) {
+				if (users[i].id == owner) {
+					switch(users[i].confirmation) {
 						case 0:
 							contentDiv.style.opacity = ".6";
 							textDiv.style.fontStyle = "italic";
