@@ -125,7 +125,7 @@ var setMailHeaderLabel;
 
     deleteMailIDs = function(ids, nView) {
         var myView = nView || view;
-        if (myView.grid && myView.grid.storage) {
+        if (myView.grid && myView.grid.collection) {
             myView.grid.deleteIDs(ids);
         }
     };
@@ -137,7 +137,7 @@ var setMailHeaderLabel;
     var json = new JSONX();
     function setAttachments(present) {
 		// if false we don't need any furthere calculations
-        if (present === false) {
+        if (!present) {
             resizeSplit("mail." + this.name + ".detail.attachments", "0em");
             return;
         }
@@ -151,7 +151,7 @@ var setMailHeaderLabel;
         // if scroll height >= 2 lines we resize the attachment div
         if (isNaN(scrollHeight) === false) {
             var height = Math.round(scrollHeight/pxPerEm);
-            if (height >= 8)  {
+            if (height >= 6)  {
                 // 3 rows max
                 should = "6.2em";
             } else if (height >= 4) {
@@ -379,7 +379,9 @@ var setMailHeaderLabel;
                 unregister("OX_Print",mail_printList);
                 unregister("OX_New_Search",searchMail);
                 unregister("OX_Delete_Search",updateAfterDeleteSearch);
-                if (view.grid && view.grid.storage) {
+                if (view.grid && view.grid.collection) {
+                    sort_order = view.grid.sort_order;
+                    sort_id = view.grid.sort_id;
                     old_focus = view.grid.focus;
                     view.grid.disable();
                 }
@@ -397,10 +399,18 @@ var setMailHeaderLabel;
                     OXCache.unregister(detailrequest.uniqueName);
                     detailrequest=null;
                 }
+                // store old sort values
+                if (type === 'newfolder') {
+                    sort_order = view.grid.sort_order;
+                    sort_id = view.grid.sort_id;
+                }
+                
                 // update headers
                 switchGridHeaders(view.grid);
                 // refresh sort
-                refreshVsplitSortEntry();
+                if (view == vsplit) {
+                    refreshVsplitSortEntry();
+                }
 
                 // note: do NOT user grid.setSort here as this results in
                 // useless request on the previous selected folder if grid
@@ -456,7 +466,7 @@ var setMailHeaderLabel;
         }
         
         function change(oldCol, newCol) {
-            if (sort_id == oldCol) sort_id = newCol;
+            if (sort_id == oldCol) grid.sort_id = sort_id = newCol;
             for (var i = 0; i < grid.columns.length; i++) {
                 var name = grid.columns[i].name;
                 for (var j = 0; j < name.length; j++) {
@@ -601,8 +611,8 @@ var setMailHeaderLabel;
         oldMessageTextType=null;
         selectedAttachments = [];
         
-        view.setAttachments(false);
         jQuery(".mail_content_view").css({ visibility: "hidden" });
+        view.setAttachments(false);
     }
 
     /**
@@ -690,7 +700,9 @@ var setMailHeaderLabel;
             grid = initGridHeader();
             $("mail." + view.name + ".grid.header").appendChild(grid.getHeader());
         }
-        //grid.sort = updateMailStorage;
+//        grid.sort = function(order, type) {
+//          sort_order = order, sort_id = type;
+//        };
         grid.getTable($("mail." + view.name + ".grid"));
         var hovercontent = createHoverContent();
         hovercontent.node.style.display="none";
@@ -1395,7 +1407,8 @@ var setMailHeaderLabel;
     }
     
     function drawMessage(view, message, folder) {
-        var nested_msgs = null, attachExists = false;
+        var nested_msgs = message.nested_msgs,
+            attachExists = nested_msgs && nested_msgs.length > 0;
         if (view != oldView) {
             oldMessage = oldMessageTextType = null;
         }
@@ -1446,9 +1459,6 @@ var setMailHeaderLabel;
                         $('mail.' + view.name + '.detail.flag').src = getFullImgSrc("img/menu/tag_" + (newField||0) + ".gif");
                     }
                     break;
-                case "nested_msgs":
-                    if(newField.length > 0) { nested_msgs = newField; attachExists = true; }
-                    break;
                 case "flags":
                     if ($('mail.' + view.name + '.detail.mailflag')) {
                        $('mail.' + view.name + '.detail.mailflag').src = getFullImgSrc("img/mail/"+getMailFlagImage(newField));
@@ -1534,7 +1544,7 @@ var setMailHeaderLabel;
             newMessageTextType="attachments_html_noimage";
         }
 
-        if (!oldMessageTextType || !oldMessage || newMessageTextType!= oldMessageTextType || !equals(message[newMessageTextType], oldMessage[newMessageTextType])) {
+        if (attachExists || !oldMessageTextType || !oldMessage || newMessageTextType!= oldMessageTextType || !equals(message[newMessageTextType], oldMessage[newMessageTextType])) {
             removeChildNodes(mda);
             mailtextchanged=true;
             for (idfield in attachmentParam) {
@@ -1597,7 +1607,7 @@ var setMailHeaderLabel;
                 }
             }
 
-            if (nested_msgs && nested_msgs != null) {
+            if (nested_msgs && nested_msgs.length > 0) {
                 mailtextchanged=true;
                 for (var nMessage = 0; nMessage < nested_msgs.length; nMessage++) {
                     (function(o) {
@@ -1701,13 +1711,13 @@ var setMailHeaderLabel;
         // set attachment display
         if (mailtextchanged) {
             if (ih && ih.document) {
-                view.setAttachments(attachExists);
+                setTimeout(function() { view.setAttachments(attachExists); }, 0);
                 ih = ih.document;
                 ih.open();
                 // safari needs explicit head/body "around" the content
                 ih.writeln('<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"'
                         + '     "http://www.w3.org/TR/html4/strict.dtd">'
-                        + '<html><head><title>' + (message.subject || "") + '</title>'
+                        + '<html><head><title>' + (escapeHTML(message.subject || "")) + '</title>'
                         + '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">'
                         + '<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=IE7">'
                         + '<link type="text/css" rel="stylesheet" href="' + ox.gui.themePath + "css/iframe.css" + '">'
@@ -1732,31 +1742,36 @@ var setMailHeaderLabel;
                         if (object.length === 3 && object[1] !== 0) {
                             var node = jQuery(".calendar-buttons", body);
                             if (node.is("div")) {
-                                var actions = { 3: _("Tentative"), 2: _("Decline"), 1: _("Accept") };
-                                jQuery.each(actions, function(idx, action) {
+                                var actions = [ { id: 3, str: _("Tentative") },
+                                                { id: 2, str: _("Decline") },
+                                                { id: 1, str: _("Accept") } ];
+                                for (var ab = 0; ab < actions.length; ab++) {
+                                    var action = actions[ab];
                                     node.append(
                                         jQuery("<a>")
                                         .attr({ href: "#" })
                                         .addClass("action link")
-                                        .text(action.toString())
-                                        .click(function(e) {
-                                            acceptdeny_updateConfirm([{
-                                                objectid: object[0],
-                                                folder_id: object[1],
-                                                module: "calendar"
-                                            }], 
-                                            idx,
-                                            "",
-                                            function() {
-                                                //deleteMails(message.folder_id, [ message ]);
-                                                //#. Status message will be shown when the confirmation status has been saved
-                                                //#. after clicking on any confirmation button in an itip mail
-                                                ox.UINotifier.ok(_("Confirmation status has been saved."));
-                                            });
-                                            return false;
-                                        })
+                                        .text(action.str.toString())
+                                        .click((function(action) {
+                                            return function(e) {
+                                                acceptdeny_updateConfirm([{
+                                                    objectid: object[0],
+                                                    folder_id: object[1],
+                                                    module: "calendar"
+                                                }], 
+                                                action.id,
+                                                "",
+                                                function() {
+                                                    //deleteMails(message.folder_id, [ message ]);
+                                                    //#. Status message will be shown when the confirmation status has been saved
+                                                    //#. after clicking on any confirmation button in an itip mail
+                                                    ox.UINotifier.ok(_("Confirmation status has been saved."));
+                                                });
+                                                return false;
+                                            };
+                                        })(action))
                                     );
-                                });
+                                };
                                 node.show();
                             }
                             delete(node);
@@ -2311,4 +2326,4 @@ register("OX_Plugins_Loaded",function () {
 });
 
 
-fileloaded();
\ No newline at end of file
+fileloaded();
