@@ -181,12 +181,12 @@ function parseDirectLinksInMails(ih) {
                      })(module[1], folder[1], id && id[1] ? id[1] : null);  
                               
             } else if (link.getAttribute("href").match(new RegExp("^(" + window.location.href + ")?#")) != null) {
+                link.setAttribute("onclick", "return false");
                 // due to an mozilla bug we run into problems with anchors in dynamic written pages 
                 // mozilla doesn't recognize that and try to load the whole page instead
                 // using this hack to jump to the anchors manually
                 for (var ia=0; ia < ih.anchors.length; ia++) {
                     if (link.getAttribute("href").match(new RegExp("^(" + window.location.href + ")?#"+ih.anchors[ia].name))) {
-                        link.setAttribute("onclick", "function() { return false; }");
                         link.onclick = (function(myDoc, myAnchor) {
                             return function(e) {
                                  myAnchor.scrollIntoView(true);
@@ -249,18 +249,22 @@ function parseDirectLinksInMails(ih) {
                 link.removeAttr("target");
                 
             } else if (href.match(new RegExp("^(" + window.location.href + ")?#")) != null) {
+                var foundAnchor = false;
                 // due to an mozilla bug we run into problems with anchors in dynamic written pages 
                 // mozilla doesn't recognize that and try to load the whole page instead
                 // using this hack to jump to the anchors manually
                 jQuery.each(ih.anchors, function(index, anchor) {
                     if (href.match(new RegExp("^(" + window.location.href + ")?#" + anchor.name))) {
+                        foundAnchor = true;
                         link.bind("click", { anchor: anchor }, function(e) {
                             e.data.anchor.scrollIntoView(true);
                             return false;
                         });
                     }
                 });
-                
+                if (!foundAnchor) {
+                    link.bind("click", function (e) { return false; });
+                }
             } else if ((href.match(/^mailto:(.+)/) || []).length === 2) {
                 var params = href.match(/^mailto:(.+)/)[1];
                 var obj = { to: params.split("?")[0] };
