@@ -494,10 +494,6 @@
         $("messaging.to").value = this.message.to.personal;
         $("messaging.message").style.height = ox.browser.WebKit ? "56%" : "60%";
     };
-    var retweetNew = new Editor("tweet", _("Retweet new"));
-    retweetNew.done = function() {
-        ox.Configuration.info(_("Retweet sent successfully"));
-    };
     
     var allServices = {
         "com.openexchange.messaging.facebook": {
@@ -543,7 +539,6 @@
             newMessage: new Editor("tweet"),
             actions: {
                 retweet: new MessageEditor("retweet", "tweet", _("Retweet")),
-                retweetNew: retweetNew,
                 directMessage: new MessageEditor("directMessage", "tweet",
                     _("Direct message"))
             },
