@@ -1191,7 +1191,6 @@ registerView(
         // use auto refresh?
         var autoRefresh = ox.api.config.get("ui.portal.autoRefresh", false) === true;
         
-
         if (bPortalNeedsRepaint) {
             // repaint
             oPortal.repaint(); // includes drawCheckboxes, getAllData
@@ -1224,6 +1223,17 @@ registerView(
     }
 );
 
+register("TimeUpdated", function() {
+    if (oPortal) {
+        if (ox.UIController.getModule() === "portal") {
+            oPortal.paint(true);
+            oPortal.drawCheckboxes();
+        } else {
+            bPortalNeedsRepaint = true;
+        }
+    }
+});
+
 function fn_clickedItem(sModule, oObj) {
     OXCache.newRequest(null, sModule, { objects: [oObj] }, null, function () {
         triggerEvent("OX_Direct_Linking", sModule, oObj);
