@@ -170,7 +170,8 @@ ox.gui.Tree = ox.gui.Widget.extend(function() {
             $(this.dom.tr).bind("click", function() {
                 clickNode(self);
                 function clickNode(node) {
-                    if (node.selectable === false) {
+                    // is node selectable and contains subfolder
+                    if (node.selectable === false && node.children.length) {
                         node.open(function() {
                             var next = node.next();
                             if (next) {
