@@ -9,6 +9,7 @@
  * Mail: info@open-xchange.com 
  * 
  * @author Viktor Pracht <viktor.pracht@open-xchange.com>
+ * @author Stefan Preuss <stefan.preuss@open-xchange.com>
  * 
  */
 
@@ -47,7 +48,7 @@ function createContent() {
             newnode("div", 0, 0, [
                 addTranslated(_("Supported Outlook versions (Connector 2 for Microsoft Outlook): Latest Versions of Microsoft Outlook 2003, Microsoft Outlook 2007, Outlook 2010 (no support of \"Office 2010 Click-to-Run\", \"Office Home and Business 2010 Testversion\")"))
             ])
-        )
+        );
     }
     
     if (getProduct("com.openexchange.oxnotifier") === true) {
@@ -64,8 +65,35 @@ function createContent() {
     return node;
 }
 
-if (configGetKey("modules")["com.openexchange.wizard"] && 
-        ox.api.config.get(["modules", "com.openexchange.oxupdater", "module"], false) === true) {
+var isProductAvailable = function () {
+    var products = ox.api.config.get(["modules", "com.openexchange.oxupdater","products"], []),
+        available = false;
+    check: for (var i=0; i < products.length; i++) {
+        var prod = products[i];
+        for (var a in prod) {
+            if (prod[a] === true) {
+                available = true;
+                break check;
+            };
+        };
+    }
+    return available && ox.api.config.get(["modules", "com.openexchange.oxupdater", "module"], false) === true;
+};
+
+var getProduct = function (key) {
+    var products = ox.api.config.get(["modules", "com.openexchange.oxupdater","products"], []);
+    for (var i=0; i < products.length; i++) {
+        var prod = products[i];
+        for (var a in prod) {
+            if (a === key) {
+                return prod[a];
+            };
+        };
+    }
+    return null;
+};
+
+if (configGetKey("modules")["com.openexchange.wizard"] && isProductAvailable() === true) {
     
     // load CSS file
     loadCSSFile(PATH + "/style.css");
@@ -163,7 +191,7 @@ if (getProduct("com.openexchange.outlook.updater.oxtender2") !== true) {
 }
 menu.show("portal");
 
-if (ox.api.config.get(["modules", "com.openexchange.oxupdater", "module"], false) === true) {
+if (isProductAvailable() === true) {
     node = new ox.Configuration.LeafNode("configuration/outlook.updater", _("Updater"));
     var page = new ox.Configuration.Page(node, _("Updater"), false);
     page.viewModified = function() { return false; };
@@ -172,16 +200,3 @@ if (ox.api.config.get(["modules", "com.openexchange.oxupdater", "module"], false
     widget.addContent = function() { this.parent.addRow(this.content); };
     page.addWidget(widget);
 }
-
-function getProduct (key) {
-    var products = ox.api.config.get(["modules", "com.openexchange.oxupdater","products"], []);
-    for (var i=0; i < products.length; i++) {
-        var prod = products[i];
-        for (var a in prod) {
-            if (a === key) {
-                return prod[a];
-            };
-        };
-    }
-    return null;
-};
